@@ -1,9 +1,8 @@
-from pycbc.frame import read_frame
+import matplotlib.pyplot as pp
 from pycbc.filter import highpass_fir, lowpass_fir
-from pycbc.waveform import get_fd_waveform
 from pycbc.psd import welch, interpolate
 from pycbc.catalog import Merger
-import pylab
+
 
 for ifo in ['H1', 'L1']:
     # Read data and remove low frequency content
@@ -25,14 +24,12 @@ for ifo in ['H1', 'L1']:
         smooth *= -1
         smooth.roll(int(.007 / smooth.delta_t))
 
-    pylab.plot(smooth.sample_times, smooth, label=ifo)
-
-pylab.legend()
-pylab.xlim(1126259462.21, 1126259462.45)
-pylab.ylim(-150, 150)
-pylab.ylabel('Smoothed-Whitened Strain')
-pylab.grid()
-pylab.xlabel('GPS Time (s)')
-pylab.show()
-
+    pp.plot(smooth.sample_times, smooth, label=ifo)
 
+pp.legend()
+pp.xlim(1126259462.21, 1126259462.45)
+pp.ylim(-150, 150)
+pp.ylabel('Smoothed-Whitened Strain')
+pp.grid()
+pp.xlabel('GPS Time (s)')
+pp.show()
