@@ -287,7 +287,8 @@ class PhaseTDStatistic(QuadratureSumStatistic):
     amplitude ratios between triggers in different ifos.
     """
 
-    def __init__(self, sngl_ranking, files=None, ifos=None, **kwargs):
+    def __init__(self, sngl_ranking, files=None, ifos=None,
+                 pregenerate_hist=True, **kwargs):
         """
         Create a statistic class instance
 
@@ -304,6 +305,10 @@ class PhaseTDStatistic(QuadratureSumStatistic):
 
         ifos: list of strs, needed here
             The list of detector names
+
+        pregenerate_hist: bool, optional
+            If False, do not pregenerate histogram on class instantiation.
+            Default is True.
         """
 
         QuadratureSumStatistic.__init__(self, sngl_ranking, files=files,
@@ -330,6 +335,8 @@ class PhaseTDStatistic(QuadratureSumStatistic):
         self.param_bin = {}
         self.two_det_flag = (len(ifos) == 2)
         self.two_det_weights = {}
+        if pregenerate_hist:
+            self.get_hist()
 
     def get_hist(self, ifos=None):
         """
@@ -1544,7 +1551,8 @@ class ExpFitFgBgNormStatistic(PhaseTDStatistic,
 
         # Safety against subclassing and not rethinking this
         allowed_names = ['ExpFitFgBgNormStatistic',
-                         'ExpFitFgBgNormBBHStatistic']
+                         'ExpFitFgBgNormBBHStatistic',
+                         'DQExpFitFgBgNormStatistic']
         self._check_coinc_lim_subclass(allowed_names)
 
         if not self.has_hist:
@@ -1726,6 +1734,152 @@ class ExpFitFgBgNormBBHStatistic(ExpFitFgBgNormStatistic):
         return loglr
 
 
+class DQExpFitFgBgNormStatistic(ExpFitFgBgNormStatistic):
+    """
+    The ExpFitFgBgNormStatistic with DQ-based reranking.
+
+    This is the same as the ExpFitFgBgNormStatistic except the likelihood
+    is multiplied by the relative signal rate based on the relevant
+    DQ likelihood value.
+    """
+
+    def __init__(self, sngl_ranking, files=None, ifos=None,
+                 **kwargs):
+        """
+        Create a statistic class instance
+
+        Parameters
+        ----------
+        sngl_ranking: str
+            The name of the ranking to use for the single-detector triggers.
+        files: list of strs, needed here
+            A list containing the filenames of hdf format files used to help
+            construct the coincident statistics. The files must have a 'stat'
+            attribute which is used to associate them with the appropriate
+            statistic class.
+        ifos: list of strs, not used here
+            The list of detector names
+        """
+        ExpFitFgBgNormStatistic.__init__(self, sngl_ranking, files=files,
+                                         ifos=ifos, **kwargs)
+        self.dq_val_by_time = {}
+        self.dq_bin_by_id = {}
+        for k in self.files.keys():
+            parsed_attrs = k.split('-')
+            if len(parsed_attrs) < 3:
+                continue
+            if parsed_attrs[2] == 'dq_ts_reference':
+                ifo = parsed_attrs[0]
+                dq_type = parsed_attrs[1]
+                dq_vals = self.assign_dq_val(k)
+                dq_bins = self.assign_bin_id(k)
+                if ifo not in self.dq_val_by_time:
+                    self.dq_val_by_time[ifo] = {}
+                    self.dq_bin_by_id[ifo] = {}
+                self.dq_val_by_time[ifo][dq_type] = dq_vals
+                self.dq_bin_by_id[ifo][dq_type] = dq_bins
+
+    def assign_bin_id(self, key):
+        """
+        Assign bin ID values
+        Assign each template id to a bin name based on a
+        referenced statistic file.
+
+        Parameters
+        ----------
+        key: str
+            statistic file key string
+
+        Returns
+        ---------
+        bin_dict: dict of strs
+            Dictionary containing the bin name for each template id
+        """
+        ifo = key.split('-')[0]
+        dq_file = self.files[key]
+        bin_names = dq_file.attrs['names'][:]
+        locs = []
+        names = []
+        for bin_name in bin_names:
+            bin_locs = dq_file[ifo + '/locs/' + bin_name][:]
+            locs = list(locs)+list(bin_locs.astype(int))
+            names = list(names)+list([bin_name]*len(bin_locs))
+        bin_dict = dict(zip(locs, names))
+        return bin_dict
+
+    def assign_dq_val(self, key):
+        """
+        Assign dq values to each time for every bin based on a
+        referenced statistic file.
+
+        Parameters
+        ----------
+        key: str
+            statistic file key string
+
+        Returns
+        ---------
+        dq_dict: dict of {time: dq_value} dicts for each bin
+            Dictionary containing the mapping between the time
+            and the dq value for each individual bin.
+
+        """
+        ifo = key.split('-')[0]
+        dq_file = self.files[key]
+        times = dq_file[ifo+'/times'][:]
+        bin_names = dq_file.attrs['names'][:]
+        dq_dict = {}
+        for bin_name in bin_names:
+            dq_vals = dq_file[ifo+'/dq_vals/'+bin_name][:]
+            dq_dict[bin_name] = dict(zip(times, dq_vals))
+        return dq_dict
+
+    def find_dq_val(self, trigs):
+        """Get dq values for a specific ifo and times"""
+        time = trigs['end_time'].astype(int)
+        try:
+            tnum = trigs.template_num
+            ifo = trigs.ifo
+        except AttributeError:
+            tnum = trigs['template_id']
+            assert len(self.ifos) == 1
+            # Should be exactly one ifo provided
+            ifo = self.ifos[0]
+        dq_val = numpy.zeros(len(time))
+        if ifo in self.dq_val_by_time:
+            for (i, t) in enumerate(time):
+                for k in self.dq_val_by_time[ifo].keys():
+                    if isinstance(tnum, numpy.ndarray):
+                        bin_name = self.dq_bin_by_id[ifo][k][tnum[i]]
+                    else:
+                        bin_name = self.dq_bin_by_id[ifo][k][tnum]
+                    val = self.dq_val_by_time[ifo][k][bin_name][int(t)]
+                    dq_val[i] = max(dq_val[i], val)
+        return dq_val
+
+    def lognoiserate(self, trigs):
+        """
+        Calculate the log noise rate density over single-ifo ranking
+
+        Read in single trigger information, compute the ranking
+        and rescale by the fitted coefficients alpha and rate
+
+        Parameters
+        -----------
+        trigs: dict of numpy.ndarrays, h5py group (or similar dict-like object)
+            Dictionary-like object holding single detector trigger information.
+
+        Returns
+        ---------
+        lognoisel: numpy.array
+            Array of log noise rate density for each input trigger.
+        """
+        logr_n = ExpFitFgBgNormStatistic.lognoiserate(
+                    self, trigs)
+        logr_n += self.find_dq_val(trigs)
+        return logr_n
+
+
 statistic_dict = {
     'quadsum': QuadratureSumStatistic,
     'single_ranking_only': QuadratureSumStatistic,
@@ -1733,6 +1887,7 @@ statistic_dict = {
     'exp_fit_stat': ExpFitStatistic,
     'exp_fit_csnr': ExpFitCombinedSNR,
     'phasetd_exp_fit_stat': PhaseTDExpFitStatistic,
+    'dq_phasetd_exp_fit_fgbg_norm': DQExpFitFgBgNormStatistic,
     'exp_fit_bg_rate': ExpFitBgRateStatistic,
     'phasetd_exp_fit_fgbg_norm': ExpFitFgBgNormStatistic,
     'phasetd_exp_fit_fgbg_bbh_norm': ExpFitFgBgNormBBHStatistic,
