@@ -474,7 +474,11 @@ def compute_max_snr_over_sky_loc_stat(hplus, hcross, hphccorr,
                                                       out=None, thresh=0,
                                                       analyse_slice=None):
     """
-    Compute the maximized over sky location statistic.
+    Matched filter maximised over polarization and orbital phase.
+
+    This implements the statistic derived in 1603.02444. It is encouraged
+    to read that work to understand the limitations and assumptions implicit
+    in this statistic before using it.
 
     Parameters
     -----------
@@ -661,9 +665,13 @@ def compute_max_snr_over_sky_loc_stat_no_phase(hplus, hcross, hphccorr,
                                                out=None, thresh=0,
                                                analyse_slice=None):
     """
-    Compute the match maximized over polarization phase.
+    Matched filter maximised over polarization phase.
 
-    In contrast to compute_max_snr_over_sky_loc_stat_no_phase this function
+    This implements the statistic derived in 1709.09181. It is encouraged
+    to read that work to understand the limitations and assumptions implicit
+    in this statistic before using it.
+
+    In contrast to compute_max_snr_over_sky_loc_stat this function
     performs no maximization over orbital phase, treating that as an intrinsic
     parameter. In the case of aligned-spin 2,2-mode only waveforms, this
     collapses to the normal statistic (at twice the computational cost!)
@@ -1316,7 +1324,7 @@ def matched_filter(template, data, psd=None, low_frequency_cutoff=None,
 _snr = None
 def match(vec1, vec2, psd=None, low_frequency_cutoff=None,
           high_frequency_cutoff=None, v1_norm=None, v2_norm=None,
-          subsample_interpolation=False):
+          subsample_interpolation=False, return_phase=False):
     """ Return the match between the two TimeSeries or FrequencySeries.
 
     Return the match between two waveforms. This is equivalent to the overlap
@@ -1345,12 +1353,16 @@ def match(vec1, vec2, psd=None, low_frequency_cutoff=None,
         quadratic fit. This can be important if measuring matches very close to
         1 and can cause discontinuities if you don't use it as matches move
         between discrete samples. If True the index returned will be a float.
+    return_phase : {False, bool}, optional
+        If True, also return the phase shift that gives the match.
 
     Returns
     -------
     match: float
     index: int
         The number of samples to shift to get the match.
+    phi: float
+        Phase to rotate complex waveform to get the match, if desired.
     """
 
     htilde = make_frequency_series(vec1)
@@ -1382,7 +1394,12 @@ def match(vec1, vec2, psd=None, low_frequency_cutoff=None,
         id_shift, maxsnr = quadratic_interpolate_peak(left, middle, right)
         max_id = max_id + id_shift
 
-    return maxsnr * snr_norm / sqrt(v2_norm), max_id
+    if return_phase:
+        rounded_max_id = int(round(max_id))
+        phi = numpy.angle(snr[rounded_max_id])
+        return maxsnr * snr_norm / sqrt(v2_norm), max_id, phi
+    else:
+        return maxsnr * snr_norm / sqrt(v2_norm), max_id
 
 def overlap(vec1, vec2, psd=None, low_frequency_cutoff=None,
           high_frequency_cutoff=None, normalized=True):
