@@ -24,13 +24,10 @@
 """Provides constructor classes and convenience functions for MCMC samplers."""
 
 from __future__ import (absolute_import, division)
-
-import os
-import signal
 import logging
 from abc import (ABCMeta, abstractmethod, abstractproperty)
 
-from six import (add_metaclass, string_types)
+from six import add_metaclass
 from six.moves import configparser as ConfigParser
 
 import numpy
@@ -38,8 +35,6 @@ import numpy
 from pycbc.filter import autocorrelation
 from pycbc.inference.io import (validate_checkpoint_files, loadfile)
 from pycbc.inference.io.base_mcmc import nsamples_in_chain
-
-from .base import setup_output
 from .base import initial_dist_from_config
 
 #
@@ -900,7 +895,7 @@ def ensemble_compute_acf(filename, start_index=None, end_index=None,
     with loadfile(filename, 'r') as fp:
         if parameters is None:
             parameters = fp.variable_params
-        if isinstance(parameters, string_types):
+        if isinstance(parameters, str):
             parameters = [parameters]
         for param in parameters:
             if per_walker:
