@@ -4,16 +4,15 @@ import pycbc
 import numpy
 import lal
 import json
-from six import u as unicode
-from glue.ligolw import ligolw
-from glue.ligolw import lsctables
-from glue.ligolw import utils as ligolw_utils
-from glue.ligolw.utils import process as ligolw_process
-from glue.ligolw.param import Param as LIGOLWParam
-from glue.ligolw.array import Array as LIGOLWArray
+from ligo.lw import ligolw
+from ligo.lw import lsctables
+from ligo.lw import utils as ligolw_utils
+from ligo.lw.utils import process as ligolw_process
+from ligo.lw.param import Param as LIGOLWParam
+from ligo.lw.array import Array as LIGOLWArray
 from pycbc import version as pycbc_version
 from pycbc import pnutils
-from pycbc.tmpltbank import return_empty_sngl
+from pycbc.io.ligolw import return_empty_sngl
 from pycbc.results import ifo_color
 from pycbc.results import source_color
 from pycbc.mchirp_area import calc_probabilities
@@ -24,11 +23,11 @@ from pycbc.mchirp_area import calc_probabilities
 def _build_series(series, dim_names, comment, delta_name, delta_unit):
     Attributes = ligolw.sax.xmlreader.AttributesImpl
     elem = ligolw.LIGO_LW(
-            Attributes({u"Name": unicode(series.__class__.__name__)}))
+            Attributes({'Name': str(series.__class__.__name__)}))
     if comment is not None:
         elem.appendChild(ligolw.Comment()).pcdata = comment
-    elem.appendChild(ligolw.Time.from_gps(series.epoch, u"epoch"))
-    elem.appendChild(LIGOLWParam.from_pyvalue(u'f0', series.f0, unit=u's^-1'))
+    elem.appendChild(ligolw.Time.from_gps(series.epoch, 'epoch'))
+    elem.appendChild(LIGOLWParam.from_pyvalue('f0', series.f0, unit='s^-1'))
     delta = getattr(series, delta_name)
     if numpy.iscomplexobj(series.data.data):
         data = numpy.row_stack((numpy.arange(len(series.data.data)) * delta,
@@ -52,10 +51,10 @@ def snr_series_to_xml(snr_series, document, sngl_inspiral_id):
     snr_lal = snr_series.lal()
     snr_lal.name = 'snr'
     snr_lal.sampleUnits = ''
-    snr_xml = _build_series(snr_lal, (u'Time', u'Time,Real,Imaginary'), None,
+    snr_xml = _build_series(snr_lal, ('Time', 'Time,Real,Imaginary'), None,
                             'deltaT', 's')
     snr_node = document.childNodes[-1].appendChild(snr_xml)
-    eid_param = LIGOLWParam.from_pyvalue(u'event_id', sngl_inspiral_id)
+    eid_param = LIGOLWParam.from_pyvalue('event_id', sngl_inspiral_id)
     snr_node.appendChild(eid_param)
 
 def make_psd_xmldoc(psddict, xmldoc=None):
@@ -65,16 +64,16 @@ def make_psd_xmldoc(psddict, xmldoc=None):
     xmldoc = ligolw.Document() if xmldoc is None else xmldoc.childNodes[0]
 
     # the PSDs must be children of a LIGO_LW with name "psd"
-    root_name = u"psd"
+    root_name = 'psd'
     Attributes = ligolw.sax.xmlreader.AttributesImpl
     lw = xmldoc.appendChild(
-        ligolw.LIGO_LW(Attributes({u"Name": root_name})))
+        ligolw.LIGO_LW(Attributes({'Name': root_name})))
 
     for instrument, psd in psddict.items():
-        xmlseries = _build_series(psd, (u"Frequency,Real", u"Frequency"),
+        xmlseries = _build_series(psd, ('Frequency,Real', 'Frequency'),
                                   None, 'deltaF', 's^-1')
         fs = lw.appendChild(xmlseries)
-        fs.appendChild(LIGOLWParam.from_pyvalue(u'instrument', instrument))
+        fs.appendChild(LIGOLWParam.from_pyvalue('instrument', instrument))
     return xmldoc
 
 class SingleCoincForGraceDB(object):
@@ -143,11 +142,13 @@ class SingleCoincForGraceDB(object):
         outdoc = ligolw.Document()
         outdoc.appendChild(ligolw.LIGO_LW())
 
+        # ligo.lw does not like `cvs_entry_time` being an empty string
+        cvs_entry_time = pycbc_version.date or None
         proc_id = ligolw_process.register_to_xmldoc(
-            outdoc, 'pycbc', {}, ifos=usable_ifos, comment='',
+            outdoc, 'pycbc', {}, instruments=usable_ifos, comment='',
             version=pycbc_version.version,
             cvs_repository='pycbc/'+pycbc_version.git_branch,
-            cvs_entry_time=pycbc_version.date).process_id
+            cvs_entry_time=cvs_entry_time).process_id
 
         # Set up coinc_definer table
         coinc_def_table = lsctables.New(lsctables.CoincDefTable)
@@ -191,7 +192,7 @@ class SingleCoincForGraceDB(object):
                 val = coinc_results['foreground/%s/%s' % (ifo, name)]
                 if name == 'end_time':
                     val += self.time_offset
-                    sngl.set_end(lal.LIGOTimeGPS(val))
+                    sngl.end = lal.LIGOTimeGPS(val)
                 else:
                     try:
                         setattr(sngl, name, val)
@@ -232,7 +233,7 @@ class SingleCoincForGraceDB(object):
             if sngl.ifo in followup_ifos:
                 for bcf in bayestar_check_fields:
                     setattr(sngl, bcf, getattr(sngl_populated, bcf))
-                sngl.set_end(lal.LIGOTimeGPS(self.merger_time))
+                sngl.end = lal.LIGOTimeGPS(self.merger_time)
 
         outdoc.childNodes[0].appendChild(coinc_event_map_table)
         outdoc.childNodes[0].appendChild(sngl_inspiral_table)
@@ -280,7 +281,7 @@ class SingleCoincForGraceDB(object):
             self.probabilities = None
 
         self.outdoc = outdoc
-        self.time = sngl_populated.get_end()
+        self.time = sngl_populated.end
 
     def save(self, filename):
         """Write this trigger to gracedb compatible xml format
@@ -290,8 +291,7 @@ class SingleCoincForGraceDB(object):
         filename: str
             Name of file to write to disk.
         """
-        gz = filename.endswith('.gz')
-        ligolw_utils.write_filename(self.outdoc, filename, gz=gz)
+        ligolw_utils.write_filename(self.outdoc, filename, compress='auto')
 
         # save source probabilities in a json file
         if self.probabilities is not None:
