@@ -16,10 +16,8 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 """Provides reference PSDs from LALSimulation.
 """
-
-import warnings
 import numbers
-from pycbc.types import FrequencySeries, zeros
+from pycbc.types import FrequencySeries
 import lal
 import lalsimulation
 import numpy
