@@ -32,7 +32,7 @@ from six.moves import StringIO
 from six.moves import configparser as ConfigParser
 
 
-class DeepCopyableConfigParser(ConfigParser.SafeConfigParser):
+class DeepCopyableConfigParser(ConfigParser.ConfigParser):
     """
     The standard SafeConfigParser no longer supports deepcopy() as of python
     2.7 (see http://bugs.python.org/issue16058). This subclass restores that
@@ -63,6 +63,7 @@ class InterpolatingConfigParser(DeepCopyableConfigParser):
         parsedFilePath=None,
         deleteTuples=None,
         skip_extended=False,
+        sanitize_newline=True,
     ):
         """
          Initialize an InterpolatingConfigParser. This reads the input configuration
@@ -164,6 +165,11 @@ class InterpolatingConfigParser(DeepCopyableConfigParser):
         if not skip_extended:
             self.perform_extended_interpolation()
 
+        # replace newlines in input with spaces
+        # this enables command line conversion compatibility
+        if sanitize_newline:
+            self.sanitize_newline()
+
         # Check for duplicate options in sub-sections
         self.sanity_check_subsections()
 
@@ -288,6 +294,19 @@ class InterpolatingConfigParser(DeepCopyableConfigParser):
                 if new_str != value:
                     self.set(section, option, new_str)
 
+    def sanitize_newline(self):
+        """
+        Filter through an ini file and replace all examples of
+        newlines with spaces. This is useful for command line conversion
+        and allow multiline configparser inputs without added backslashes
+        """
+
+        # Do not allow any interpolation of the section names
+        for section in self.sections():
+            for option, value in self.items(section):
+                new_value = value.replace('\n', ' ').replace('\r', ' ')
+                self.set(section, option, new_value)
+
     def interpolate_string(self, test_string, section):
         """
         Take a string and replace all example of ExtendedInterpolation
