@@ -409,7 +409,7 @@ class FrequencySeries(Array):
             _numpy.savetxt(path, output)
         elif ext == '.xml' or path.endswith('.xml.gz'):
             from pycbc.io.live import make_psd_xmldoc
-            from glue.ligolw import utils
+            from ligo.lw import utils
 
             if self.kind != 'real':
                 raise ValueError('XML only supports real frequency series')
