@@ -25,23 +25,23 @@
 """
 This module provides classes that describe banks of waveforms
 """
-import sys
 import types
 import logging
 import os.path
 import h5py
 from copy import copy
 import numpy as np
-from glue.ligolw import ligolw, table, lsctables, utils as ligolw_utils
+from ligo.lw import lsctables, utils as ligolw_utils
 import pycbc.waveform
 import pycbc.pnutils
 import pycbc.waveform.compress
 from pycbc import DYN_RANGE_FAC
 from pycbc.types import FrequencySeries, zeros
 import pycbc.io
-import six
+from pycbc.io.ligolw import LIGOLWContentHandler
 import hashlib
 
+
 def sigma_cached(self, psd):
     """ Cache sigma calculate for use in tandem with the FilterBank class
     """
@@ -99,10 +99,6 @@ def sigma_cached(self, psd):
             self._sigmasq[key] = self.sigma_view.inner(psd.invsqrt[self.sslice])
     return self._sigmasq[key]
 
-# dummy class needed for loading LIGOLW files
-class LIGOLWContentHandler(ligolw.LIGOLWContentHandler):
-    pass
-lsctables.use_in(LIGOLWContentHandler)
 
 # helper function for parsing approximant strings
 def boolargs_from_apprxstr(approximant_strs):
@@ -168,6 +164,7 @@ def add_approximant_arg(parser, default=None, help=None):
                         metavar='APPRX[:COND]',
                         help=help)
 
+
 def parse_approximant_arg(approximant_arg, warray):
     """Given an approximant arg (see add_approximant_arg) and a field
     array, figures out what approximant to use for each template in the array.
@@ -204,12 +201,11 @@ def tuple_to_hash(tuple_to_be_hashed):
     int
         an integer representation of the hashed array
     """
-    if six.PY2:
-        return hash(tuple_to_be_hashed)
     h = hashlib.blake2b(np.array(tuple_to_be_hashed).tobytes('C'),
                         digest_size=8)
     return np.fromstring(h.digest(), dtype=int)[0]
 
+
 class TemplateBank(object):
     """Class to provide some basic helper functions and information
     about elements of a template bank.
@@ -247,7 +243,6 @@ class TemplateBank(object):
         Any additional keyword arguments are stored to the `extra_args`
         attribute.
 
-
     Attributes
     ----------
     table : WaveformArray
@@ -275,8 +270,7 @@ class TemplateBank(object):
             self.filehandler = None
             self.indoc = ligolw_utils.load_filename(
                 filename, False, contenthandler=LIGOLWContentHandler)
-            self.table = table.get_table(
-                self.indoc, lsctables.SnglInspiralTable.tableName)
+            self.table = lsctables.SnglInspiralTable.get_table(self.indoc)
             self.table = pycbc.io.WaveformArray.from_ligolw_table(self.table,
                 columns=parameters)
 
@@ -338,13 +332,9 @@ class TemplateBank(object):
         # (if anything was in the file)
         if approximant is not None:
             # get the approximant for each template
-            # FIXME: Remove if block once python2 is retired
-            if sys.version_info >= (3, 0):
-                dtype = h5py.string_dtype(encoding='utf-8')
-                apprxs = np.array(self.parse_approximant(approximant),
-                                  dtype=dtype)
-            else:
-                apprxs = self.parse_approximant(approximant)
+            dtype = h5py.string_dtype(encoding='utf-8')
+            apprxs = np.array(self.parse_approximant(approximant),
+                              dtype=dtype)
             if 'approximant' not in self.table.fieldnames:
                 self.table = self.table.add_fields(apprxs, 'approximant')
             else:
@@ -437,7 +427,6 @@ class TemplateBank(object):
     def end_frequency(self, index):
         """ Return the end frequency of the waveform at the given index value
         """
-        from pycbc.waveform.waveform import props
         if hasattr(self.table[index], 'f_final'):
             return self.table[index].f_final
 
@@ -498,7 +487,6 @@ class TemplateBank(object):
         indices_unique= np.unique(indices_combined)
         self.table = self.table[indices_unique]
 
-
     def ensure_standard_filter_columns(self, low_frequency_cutoff=None):
         """ Initialize FilterBank common fields
 
@@ -525,6 +513,7 @@ class TemplateBank(object):
         if self.f_lower is None and self.min_f_lower == 0.:
             raise ValueError('Invalid low-frequency cutoff settings')
 
+
 class LiveFilterBank(TemplateBank):
     def __init__(self, filename, sample_rate, minimum_buffer,
                        approximant=None, increment=8, parameters=None,
@@ -592,7 +581,6 @@ class LiveFilterBank(TemplateBank):
         return self.get_template(index)
 
     def get_template(self, index, min_buffer=None):
-
         approximant = self.approximant(index)
         f_end = self.end_frequency(index)
         flow = self.table[index].f_lower
@@ -607,6 +595,8 @@ class LiveFilterBank(TemplateBank):
         p = props(self.table[index])
         p.pop('approximant')
         buff_size = pycbc.waveform.get_waveform_filter_length_in_time(approximant, **p)
+        if not buff_size:
+            raise RuntimeError('Template waveform %s not recognized!' % approximant)
 
         tlen = self.round_up((buff_size + min_buffer) * self.sample_rate)
         flen = int(tlen / 2 + 1)
@@ -614,17 +604,17 @@ class LiveFilterBank(TemplateBank):
         delta_f = self.sample_rate / float(tlen)
 
         if f_end is None or f_end >= (flen * delta_f):
-            f_end = (flen-1) * delta_f
+            f_end = (flen - 1) * delta_f
 
         logging.info("Generating %s, %ss, %i, starting from %s Hz",
-                     approximant, 1.0/delta_f, index, flow)
+                     approximant, 1.0 / delta_f, index, flow)
 
         # Get the waveform filter
         distance = 1.0 / DYN_RANGE_FAC
         htilde = pycbc.waveform.get_waveform_filter(
             zeros(flen, dtype=np.complex64), self.table[index],
             approximant=approximant, f_lower=flow, f_final=f_end,
-            delta_f=delta_f, delta_t=1.0/self.sample_rate, distance=distance,
+            delta_f=delta_f, delta_t=1.0 / self.sample_rate, distance=distance,
             **self.extra_args)
 
         # If available, record the total duration (which may
@@ -825,6 +815,7 @@ class FilterBank(TemplateBank):
         htilde._sigmasq = {}
         return htilde
 
+
 def find_variable_start_frequency(approximant, parameters, f_start, max_length,
                                   delta_f = 1):
     """ Find a frequency value above the starting frequency that results in a
@@ -932,3 +923,9 @@ class FilterBankSkyMax(TemplateBank):
         hcross._sigmasq = {}
 
         return hplus, hcross
+
+
+__all__ = ('sigma_cached', 'boolargs_from_apprxstr', 'add_approximant_arg',
+           'parse_approximant_arg', 'tuple_to_hash', 'TemplateBank',
+           'LiveFilterBank', 'FilterBank', 'find_variable_start_frequency',
+           'FilterBankSkyMax')
