@@ -446,13 +446,13 @@ class WorkflowConfigParser(InterpolatingConfigParser):
         # expand executable which statements
         self.perform_exe_expansion()
 
-        # Check for any substitutions that can be made
-        self.perform_extended_interpolation()
-
         # Resolve any URLs needing resolving
         self.curr_resolved_files = {}
         self.resolve_urls()
 
+        # Check for any substitutions that can be made
+        self.perform_extended_interpolation()
+
     def perform_exe_expansion(self):
         """
         This function will look through the executables section of the
@@ -604,7 +604,9 @@ class WorkflowConfigParser(InterpolatingConfigParser):
         for section in self.sections():
             for option, value in self.items(section):
                 # Check the value
-                new_str = self.resolve_file_url(value)
+                value_l = value.split(' ')
+                new_str_l = [self.resolve_file_url(val) for val in value_l]
+                new_str = ' '.join(new_str_l)
                 if new_str is not None and new_str != value:
                     self.set(section, option, new_str)
 
@@ -639,9 +641,9 @@ class WorkflowConfigParser(InterpolatingConfigParser):
         # ${ ... } form I may not have to do anything
 
         # Strip the ${ and }
-        test_string = test_string[2:-1]
+        test_string_strip = test_string[2:-1]
 
-        test_list = test_string.split(":", 1)
+        test_list = test_string_strip.split(":", 1)
 
         if len(test_list) == 2:
             if test_list[0] == "resolve":
@@ -652,4 +654,4 @@ class WorkflowConfigParser(InterpolatingConfigParser):
                 self.curr_resolved_files[curr_lfn] = local_url
                 return local_url
 
-        return None
+        return test_string
