@@ -36,7 +36,7 @@ from six.moves import configparser as ConfigParser
 import pycbc
 from pycbc.workflow.core import FileList
 from pycbc.workflow.core import make_analysis_dir, resolve_url_to_file
-from pycbc.workflow.jobsetup import select_tmpltbank_class, select_matchedfilter_class, sngl_ifo_job_setup
+from pycbc.workflow.jobsetup import select_tmpltbank_class, sngl_ifo_job_setup
 
 def setup_tmpltbank_workflow(workflow, science_segs, datafind_outs,
                              output_dir=None, psd_files=None, tags=None,
@@ -50,7 +50,7 @@ def setup_tmpltbank_workflow(workflow, science_segs, datafind_outs,
     ----------
     workflow: pycbc.workflow.core.Workflow
         An instanced class that manages the constructed workflow.
-    science_segs : Keyed dictionary of glue.segmentlist objects
+    science_segs : Keyed dictionary of ligo.segments.segmentlist objects
         scienceSegs[ifo] holds the science segments to be analysed for each
         ifo.
     datafind_outs : pycbc.workflow.core.FileList
@@ -86,34 +86,8 @@ def setup_tmpltbank_workflow(workflow, science_segs, datafind_outs,
     # Else we assume template banks will be generated in the workflow
     elif tmpltbankMethod == "WORKFLOW_INDEPENDENT_IFOS":
         logging.info("Adding template bank jobs to workflow.")
-        if cp.has_option_tags("workflow-tmpltbank",
-                              "tmpltbank-link-to-matchedfilter", tags):
-            if not cp.has_option_tags("workflow-matchedfilter",
-                              "matchedfilter-link-to-tmpltbank", tags):
-                errMsg = "If using tmpltbank-link-to-matchedfilter, you should "
-                errMsg = "also use matchedfilter-link-to-tmpltbank."
-                logging.warn(errMsg)
-            linkToMatchedfltr = True
-        else:
-            linkToMatchedfltr = False
-        if cp.has_option_tags("workflow-tmpltbank",
-                              "tmpltbank-compatibility-mode", tags):
-            if not linkToMatchedfltr:
-                errMsg = "Compatibility mode requires that the "
-                errMsg += "tmpltbank-link-to-matchedfilter option is also set."
-                raise ValueError(errMsg)
-            if not cp.has_option_tags("workflow-matchedfilter",
-                              "matchedfilter-compatibility-mode", tags):
-                errMsg = "If using compatibility mode it must be set both in "
-                errMsg += "the template bank and matched-filtering stages."
-                raise ValueError(errMsg)
-            compatibility_mode = True
-        else:
-            compatibility_mode = False
         tmplt_banks = setup_tmpltbank_dax_generated(workflow, science_segs,
                                          datafind_outs, output_dir, tags=tags,
-                                         link_to_matchedfltr=linkToMatchedfltr,
-                                         compatibility_mode=compatibility_mode,
                                          psd_files=psd_files)
     elif tmpltbankMethod == "WORKFLOW_INDEPENDENT_IFOS_NODATA":
         logging.info("Adding template bank jobs to workflow.")
@@ -157,8 +131,6 @@ def setup_tmpltbank_workflow(workflow, science_segs, datafind_outs,
 
 def setup_tmpltbank_dax_generated(workflow, science_segs, datafind_outs,
                                   output_dir, tags=None,
-                                  link_to_matchedfltr=True,
-                                  compatibility_mode=False,
                                   psd_files=None):
     '''
     Setup template bank jobs that are generated as part of the CBC workflow.
@@ -173,7 +145,7 @@ def setup_tmpltbank_dax_generated(workflow, science_segs, datafind_outs,
     ----------
     workflow: pycbc.workflow.core.Workflow
         An instanced class that manages the constructed workflow.
-    science_segs : Keyed dictionary of glue.segmentlist objects
+    science_segs : Keyed dictionary of ligo.segments.segmentlist objects
         scienceSegs[ifo] holds the science segments to be analysed for each
         ifo.
     datafind_outs : pycbc.workflow.core.FileList
@@ -183,11 +155,6 @@ def setup_tmpltbank_dax_generated(workflow, science_segs, datafind_outs,
     tags : list of strings
         If given these tags are used to uniquely name and identify output files
         that would be produced in multiple calls to this function.
-    link_to_matchedfltr : boolean, optional (default=True)
-        If this option is given, the job valid_times will be altered so that
-        there will be one inspiral file for every template bank and they will
-        cover the same time span. Note that this option must also be given
-        during matched-filter generation to be meaningful.
     psd_file : pycbc.workflow.core.FileList
         The file list containing predefined PSDs, if provided.
 
@@ -208,30 +175,9 @@ def setup_tmpltbank_dax_generated(workflow, science_segs, datafind_outs,
     # Select the appropriate class
     exe_class = select_tmpltbank_class(tmplt_bank_exe)
 
-    # The exe instance needs to know what data segments are analysed, what is
-    # discarded etc. This should *not* be hardcoded, so using a new executable
-    # will require a bit of effort here ....
-
-    if link_to_matchedfltr:
-        # Use this to ensure that inspiral and tmpltbank jobs overlap. This
-        # means that there will be 1 inspiral job for every 1 tmpltbank and
-        # the data read in by both will overlap as much as possible. (If you
-        # ask the template bank jobs to use 2000s of data for PSD estimation
-        # and the matched-filter jobs to use 4000s, you will end up with
-        # twice as many matched-filter jobs that still use 4000s to estimate a
-        # PSD but then only generate triggers in the 2000s of data that the
-        # template bank jobs ran on.
-        tmpltbank_exe = os.path.basename(cp.get('executables', 'inspiral'))
-        link_exe_instance = select_matchedfilter_class(tmpltbank_exe)
-    else:
-        link_exe_instance = None
-
     # Set up class for holding the banks
     tmplt_banks = FileList([])
 
-
-    # Template banks are independent for different ifos, but might not be!
-    # Begin with independent case and add after FIXME
     for ifo in ifos:
         job_instance = exe_class(workflow.cp, 'tmpltbank', ifo=ifo,
                                                out_dir=output_dir,
@@ -242,16 +188,9 @@ def setup_tmpltbank_dax_generated(workflow, science_segs, datafind_outs,
         else:
             job_instance.write_psd = False
 
-        if link_exe_instance:
-            link_job_instance = link_exe_instance(cp, 'inspiral', ifo=ifo,
-                        out_dir=output_dir, tags=tags)
-        else:
-            link_job_instance = None
         sngl_ifo_job_setup(workflow, ifo, tmplt_banks, job_instance,
                            science_segs[ifo], datafind_outs,
-                           link_job_instance=link_job_instance,
-                           allow_overlap=True,
-                           compatibility_mode=compatibility_mode)
+                           allow_overlap=True)
     return tmplt_banks
 
 def setup_tmpltbank_without_frames(workflow, output_dir,
